@@ -15,8 +15,8 @@ draw.boxes = function(
 		labelAdj = "center",
 		labelOverflow = TRUE,
 		labelFamily = "sans",
-		colorVal = "#BBBBBB",
-		colorFun = function() NULL,
+		labelColor = "#000000",
+		fillColor = "#BBBBBB",
 		border = "#666666",
 		cex.lab = 1,
 		spacing = 0.2,
@@ -25,6 +25,8 @@ draw.boxes = function(
 		groupPosition = NA,
 		groupSize = NA,
 		groupLwd = 1,
+		fg = "#000000",
+		normalize.y = TRUE,
 		...
 	) {
 	# Coercions
@@ -46,6 +48,7 @@ draw.boxes = function(
 		end = end,
 		cex.lab = cex.lab,
 		bty = bty,
+		fg = fg,
 		...	
 	)
 	
@@ -142,22 +145,27 @@ draw.boxes = function(
 			}
 			
 			# Maximal depth used
-			maxLine <- max(boxes$yline) + 1L
+			if(isTRUE(normalize.y)) { maxLine <- max(boxes$yline) + 1L
+			} else                  { maxLine <- 1L
+			}
 			
 			
 			
 			## FEATURE PLOTING ##
 			
-			# Color function
-			if(is.na(colorVal)) {
-				environment(colorFun) <- environment()
-				color <- colorFun()
-			} else {
-				color <- colorVal
+			# Box filling
+			if(is.function(fillColor)) {
+				environment(fillColor) <- environment()
+				fillColor <- fillColor()
 			}
 			
-			# Repercute to border
-			if(identical(border, "color")) border <- color
+			# Box border
+			if(is.function(border)) {
+				environment(border) <- environment()
+				border <- border()
+			} else if(identical(border, "fillColor")) {
+				border <- fillColor
+			}
 			
 			# Group bonds
 			if(!is.na(groupBy)) {
@@ -166,11 +174,14 @@ draw.boxes = function(
 					y0 = (boxes$yline + 0.5) / maxLine,
 					x1 = boxes$end.plot,
 					y1 = (boxes$yline + 0.5) / maxLine,
-					col = border,
+					col = fg,
 					lwd = groupLwd
 				)
 			}
 			
+			# Dynamic spacing
+			if(is.character(spacing)) spacing <- slice[[ spacing ]]
+			
 			# Individual boxes (limit to plotting range to work around R plot bug)
 			slice$start <- pmax(graphics::par("usr")[1], slice$start)
 			slice$end   <- pmin(graphics::par("usr")[2], slice$end)
@@ -179,7 +190,7 @@ draw.boxes = function(
 				xright = slice$end,
 				ytop = (slice$plotLine + (1 - spacing/2)) / maxLine,
 				ybottom = (slice$plotLine + spacing/2) / maxLine,
-				col = color,
+				col = fillColor,
 				border = border
 			)
 			
@@ -194,7 +205,7 @@ draw.boxes = function(
 						ybottom = (boxes$yline + 0.5) / maxLine - charHeight/2,
 						ytop = (boxes$yline + 0.5) / maxLine + charHeight/2,
 						col = "#FFFFFF",
-						border = border
+						border = fg
 					)		
 				}
 				
@@ -204,6 +215,12 @@ draw.boxes = function(
 					boxes[ boxes$strand == "+" , "label" ] <- sprintf("%s >", boxes[ boxes$strand == "+" , "label" ])
 				}
 				
+				# Label color
+				if(is.function(labelColor)) {
+					environment(labelColor) <- environment()
+					labelColor <- labelColor()
+				}
+				
 				# Plotting arguments
 				args <- with(
 					boxes[ (isTRUE(label) && isTRUE(labelOverflow)) | !boxes$overflow ,],
@@ -211,7 +228,7 @@ draw.boxes = function(
 						x = (start.lab + end.lab) / 2,
 						y = (yline + 0.5) / maxLine,
 						label = label,
-						col = "#000000",
+						col = labelColor,
 						adj = c(0.5, 0.5),
 						cex = labelCex,
 						srt = labelSrt
@@ -224,7 +241,7 @@ draw.boxes = function(
 				}
 				
 				# Execute plotting
-				do.call(graphics::text, args)
+				if(length(args$label) > 0L) do.call(graphics::text, args)
 			}
 		}
 	}
@@ -235,7 +252,7 @@ draw.boxes = function(
 			x = mean(graphics::par("usr")[1:2]),
 			y = mean(graphics::par("usr")[3:4]),
 			label = errorMessage,
-			col = "#000000",
+			col = fg,
 			adj = c(0.5, 0.5),
 			cex = cex.lab
 		)
@@ -244,7 +261,7 @@ draw.boxes = function(
 	# Surrounding box
 	graphics::box(
 		which = "plot",
-		col = "#000000",
+		col = fg,
 		bty = bty
 	)
 }
